from .detector.app_monitor import AppMonitor

class HanifX_v19:
    def __init__(self):
        self.monitor = AppMonitor()

    def run_scan(self):
        print("🔒 HanifX v19.0.0 Real-time App Guard Running...")
        new_apps = self.monitor.detect_new_apps()
        if new_apps:
            print("⚠️ Suspicious Apps Found:")
            for pkg_name, apk_path in new_apps:
                print("  →", pkg_name, "(APK:", apk_path, ")")
        else:
            print("✅ No new apps detected.")



import os
from datetime import datetime

APP_LIST_FILE = "logs/app_list.txt"
LOG_FILE = "logs/detected.log"

def ensure_dirs():
    if not os.path.exists("logs"):
        os.makedirs("logs")

def load_previous_list():
    ensure_dirs()
    if not os.path.exists(APP_LIST_FILE):
        return []
    apps = []
    with open(APP_LIST_FILE, "r") as f:
        for line in f.readlines():
            pkg, path = line.strip().split("::")
            apps.append((pkg, path))
    return apps

def save_current_list(apps):
    ensure_dirs()
    with open(APP_LIST_FILE, "w") as f:
        for pkg, path in apps:
            f.write(pkg + "::" + path + "\n")

def save_log(message):
    ensure_dirs()
    timestamp = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
    full_message = f"[{timestamp}] {message}"
    print(full_message)
    with open(LOG_FILE, "a") as f:
        f.write(full_message + "\n")



from setuptools import setup, find_packages

setup(
    name="hanifx",
    version="19.0.0",
    author="Hanif",
    author_email="sajim4653@gmail.com",
    description="HanifX v19.0.0 - Real-time Auto App Detection",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/hanifx-540",
    packages=find_packages(),
    python_requires=">=3.8",
    install_requires=[],
    entry_points={
        "console_scripts": [
            "hanifx-scan=hanifx.v19:HanifX_v19",
        ],
    },
)



import subprocess
from .utils import load_previous_list, save_current_list, save_log

class AppMonitor:
    def __init__(self):
        pass

    def get_installed_apps(self):
        """ADB/Termux compatible installed apps fetch"""
        try:
            result = subprocess.check_output(["adb", "shell", "pm", "list", "packages", "-f"])
            apps = []
            for line in result.splitlines():
                line = line.decode().strip()
                if line.startswith("package:"):
                    parts = line.replace("package:", "").split("=")
                    if len(parts) == 2:
                        apk_path, pkg_name = parts
                        apps.append((pkg_name, apk_path))
            return apps
        except Exception as e:
            save_log(f"❌ Error fetching apps: {e}")
            return []

    def detect_new_apps(self):
        prev_apps = load_previous_list()
        curr_apps = self.get_installed_apps()

        prev_names = [x[0] for x in prev_apps]
        new_apps = [pkg for pkg in curr_apps if pkg[0] not in prev_names]

        if new_apps:
            for pkg_name, apk_path in new_apps:
                save_log(f"⚠️ New/Hidden App Detected: {pkg_name} (APK: {apk_path})")

        save_current_list(curr_apps)
        return new_apps
